psql

package module
v0.0.0-...-77ee7f3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 29, 2022 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

package psql is mainly to give interface to manage psql db query's and stuff

package psql utils.go is for fn used in psql but not necessary to be accessible outside of the package

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type DbInterface

type DbInterface interface {
	Exec(string) error
	Ping() error
	QuerySelect(string) ([]map[string]any, error)
}

DbInterface to package all methods and to be accessible and understanable

func Psql_connect

func Psql_connect() (DbInterface, error)

Psql_connect is main initialize fn, that connect to db and give interface

Jump to